@@ -43,5 +43,5 @@ if (getRversion() >= "2.15.1") {
     "rate_missing", "rate_outlier", "rgb", "runif", "se_mean", "statistic", 
     "status", "top_freq", "types", "unique_count", "unique_rate", "variable_1", 
     "variable_2", "variables", "zero_count", "reportData", "predictors", "x",
-    "described_variables", "index"))
+    "described_variables", "index", "compareVersion"))
 }
\ No newline at end of file
